
/**************************************************************************
 * 
 * Copyright 2016 Novartis Institutes for BioMedical Research Inc.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *************************************************************************/


#ifndef _GLOBAL_H_
#define _GLOBAL_H_

#include <hdf5.h>
#include <hdf5_hl.h>


#include <R.h>
#include <Rdefines.h>
#include <Rinternals.h>
#include <R_ext/Rdynload.h>
#include <R_ext/Error.h>

#include "HelperStructs.h"

#include "H5Error.h"
#include "H5ls.h"
#include "convert.h"
#include "datatype_export.h"
#include "const_export.h"
#include "Wrapper_manual_H5T.h"

#include "Wrapper_auto_H5A.h"
#include "Wrapper_auto_H5D.h"
#include "Wrapper_auto_H5E.h"
#include "Wrapper_auto_H5F.h"
#include "Wrapper_auto_H5G.h"
#include "Wrapper_auto_H5I.h"
#include "Wrapper_auto_H5L.h"
#include "Wrapper_auto_H5O.h"
#include "Wrapper_auto_H5P.h"
#include "Wrapper_auto_H5.h"
#include "Wrapper_auto_H5R.h"
#include "Wrapper_auto_H5S.h"
#include "Wrapper_auto_H5T.h"
#include "Wrapper_auto_H5Z.h"
#include "Wrapper_auto_H5DS.h"
#include "Wrapper_auto_H5IM.h"
#include "Wrapper_auto_H5LT.h"
#include "Wrapper_auto_H5TB.h"
#include "Wrapper_auto_H5FDcore.h"
#include "Wrapper_auto_H5FDfamily.h"
#include "Wrapper_auto_H5FDlog.h"
#include "Wrapper_auto_H5FDsec2.h"
#include "Wrapper_auto_H5FDstdio.h"

// #include "H5Tnative_r.h"


#endif
